@@ -86,7 +86,7 @@ sub as_text {
 
     my $vars = $self->vars_as_hash;
     return join("\n",
-                $self->file_path,
+                '_file_name ' . $self->file_path,
                 map $_ . ' ' . $vars->{$_}, sort keys %$vars) . "\n";
 }
 
@@ -99,7 +99,17 @@ sub save {
 }
 
 
-no Moose;
+sub file_to_text {
+    ## Class method. Returns text metadata for the specified file.
+    my $class = shift;
+    my ($path) = @_;
+
+    my $metadata = $class->new_from_path($path);
+    return $metadata->as_text;
+}
+
+
+no Any::Moose;
 
 1;
 
@@ -110,10 +120,6 @@ __END__
 
 Audio::Metadata - Manipulate metadata in audio files
 
-=head1 VERSION
-
-Version 0.04
-
 =cut
 
 =head1 DESCRIPTION
@@ -188,6 +194,14 @@ Writes metadata to file.
 
 =back
 
+=head3 C<file_to_text($path)>
+
+=over
+
+Class method. Returns text metadata for the specified file. 
+
+=back
+
 =head1 AUTHOR
 
 Egor Shipovalov, C<< <kogdaugodno at gmail.com> >>
